gchecky.model.authorization_amount_notification_t

Package gchecky :: Module model :: Class authorization_amount_notification_t |
[hide private]
[frames] | no frames]

# Class authorization_amount_notification_t

source code

         object --+
                  |
          gxml.Node --+
                      |
          gxml.Document --+
                          |
    abstract_notification_t --+
                              |
                             authorization_amount_notification_t

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``authorization-amount-notification``'`` The document's unique xml tag name.
| authorization_amount = `Node:PATH(authorization-amount):REQ:{ p`...``
| authorization_expiration_date = `Timestamp:PATH(authorization-e`...``
| avs_response = `String:PATH(avs-response):REQ:VALS("Y","P","A",`...``
| cvn_response = `String:PATH(cvn-response):REQ:VALS("M","N","U",`...``
| _fields = ``{``'``authorization_amount``'``:` Node:PATH(authorization-amo`...`` list of meta-Fields of this class.
Inherited from `abstract_notification_t`: `google_order_number`, `serial_number`, `timestamp`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### authorization_amount Value:
      Node:PATH(authorization-amount):REQ:{ price_t }

  ### authorization_expiration_date Value:
      Timestamp:PATH(authorization-expiration-date):REQ

  ### avs_response Value:
      String:PATH(avs-response):REQ:VALS("Y","P","A","N","U")

  ### cvn_response Value:
      String:PATH(cvn-response):REQ:VALS("M","N","U","E")

  ### _fields list of meta-Fields of this class. Value:
      {'authorization_amount': Node:PATH(authorization-amount):REQ:{ price_t
       },
       'authorization_expiration_date': Timestamp:PATH(authorization-expirat
      ion-date):REQ,
       'avs_response': String:PATH(avs-response):REQ:VALS("Y","P","A","N","U
      "),
       'cvn_response': String:PATH(cvn-response):REQ:VALS("M","N","U","E"),
       'google_order_number': ID:PATH(google-order-number):REQ,
      ...